@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = ctx => ({
   locales: {
     '/': {
       lang: 'en-US',
@@ -26,20 +26,58 @@ module.exports = {
       description: 'Vue.js 공식 라우터'
     },
     '/fr/': {
-        lang: 'fr',
-        title: 'Vue Router',
-        description: 'Routeur officiel pour Vue.Js'
+      lang: 'fr',
+      title: 'Vue Router',
+      description: 'Routeur officiel pour Vue.Js'
     }
   },
-  serviceWorker: true,
-  theme: 'vue',
+  head: [
+    ['link', { rel: 'icon', href: `/logo.png` }],
+    [
+      'link',
+      { rel: 'apple-touch-icon', href: `/icons/apple-touch-icon-152x152.png` }
+    ],
+    [
+      'link',
+      {
+        rel: 'mask-icon',
+        href: '/icons/safari-pinned-tab.svg',
+        color: '#3eaf7c'
+      }
+    ],
+    [
+      'meta',
+      {
+        name: 'msapplication-TileImage',
+        content: '/icons/msapplication-icon-144x144.png'
+      }
+    ]
+  ],
+  // theme: '@vuepress/vue',
+  plugins: [
+    [
+      '@vuepress/pwa',
+      {
+        serviceWorker: true,
+        updatePopup: true
+      }
+    ]
+  ],
   themeConfig: {
-    algolia: {
-      apiKey: 'f854bb46d3de7eeb921a3b9173bd0d4c',
-      indexName: 'vue-router',
+    algolia: ctx.isProd
+      ? {
+          apiKey: 'f854bb46d3de7eeb921a3b9173bd0d4c',
+          indexName: 'vue-router'
+        }
+      : null,
+    carbonAds: {
+      carbon: 'CEBICK3I',
+      custom: 'CEBICK3M',
+      placement: 'routervuejsorg'
     },
     repo: 'vuejs/vue-router',
     docsDir: 'docs',
+    smoothScroll: true,
     locales: {
       '/': {
         label: 'English',
@@ -86,7 +124,8 @@ module.exports = {
               '/guide/advanced/transitions.md',
               '/guide/advanced/data-fetching.md',
               '/guide/advanced/scroll-behavior.md',
-              '/guide/advanced/lazy-loading.md'
+              '/guide/advanced/lazy-loading.md',
+              '/guide/advanced/navigation-failures.md'
             ]
           }
         ]
@@ -236,7 +275,8 @@ module.exports = {
               '/ru/guide/advanced/transitions.md',
               '/ru/guide/advanced/data-fetching.md',
               '/ru/guide/advanced/scroll-behavior.md',
-              '/ru/guide/advanced/lazy-loading.md'
+              '/ru/guide/advanced/lazy-loading.md',
+              '/ru/guide/advanced/navigation-failures.md'
             ]
           }
         ]
@@ -292,55 +332,55 @@ module.exports = {
         ]
       },
       '/fr/': {
-          label: 'Français',
-          selectText: 'Langues',
-          editLinkText: 'Editer cette page sur Github',
-          nav: [
-              {
-                  text: 'Guide',
-                  link: '/fr/guide/'
-              },
-              {
-                  text: 'API',
-                  link: '/fr/api/'
-              },
-              {
-                  text: 'Notes de version',
-                  link: 'https://github.com/vuejs/vue-router/releases'
-              }
-          ],
-          sidebar: [
-              '/fr/installation.md',
-              '/fr/',
-              {
-                  title: 'Essentiels',
-                  collapsable: false,
-                  children: [
-                      '/fr/guide/',
-                      '/fr/guide/essentials/dynamic-matching.md',
-                      '/fr/guide/essentials/nested-routes.md',
-                      '/fr/guide/essentials/navigation.md',
-                      '/fr/guide/essentials/named-routes.md',
-                      '/fr/guide/essentials/named-views.md',
-                      '/fr/guide/essentials/redirect-and-alias.md',
-                      '/fr/guide/essentials/passing-props.md',
-                      '/fr/guide/essentials/history-mode.md'
-                  ]
-              },
-              {
-                  title: 'Avancés',
-                  collapsable: false,
-                  children: [
-                      '/fr/guide/advanced/navigation-guards.md',
-                      '/fr/guide/advanced/meta.md',
-                      '/fr/guide/advanced/transitions.md',
-                      '/fr/guide/advanced/data-fetching.md',
-                      '/fr/guide/advanced/scroll-behavior.md',
-                      '/fr/guide/advanced/lazy-loading.md'
-                  ]
-              }
-          ]
-      },
+        label: 'Français',
+        selectText: 'Langues',
+        editLinkText: 'Editer cette page sur Github',
+        nav: [
+          {
+            text: 'Guide',
+            link: '/fr/guide/'
+          },
+          {
+            text: 'API',
+            link: '/fr/api/'
+          },
+          {
+            text: 'Notes de version',
+            link: 'https://github.com/vuejs/vue-router/releases'
+          }
+        ],
+        sidebar: [
+          '/fr/installation.md',
+          '/fr/',
+          {
+            title: 'Essentiels',
+            collapsable: false,
+            children: [
+              '/fr/guide/',
+              '/fr/guide/essentials/dynamic-matching.md',
+              '/fr/guide/essentials/nested-routes.md',
+              '/fr/guide/essentials/navigation.md',
+              '/fr/guide/essentials/named-routes.md',
+              '/fr/guide/essentials/named-views.md',
+              '/fr/guide/essentials/redirect-and-alias.md',
+              '/fr/guide/essentials/passing-props.md',
+              '/fr/guide/essentials/history-mode.md'
+            ]
+          },
+          {
+            title: 'Avancés',
+            collapsable: false,
+            children: [
+              '/fr/guide/advanced/navigation-guards.md',
+              '/fr/guide/advanced/meta.md',
+              '/fr/guide/advanced/transitions.md',
+              '/fr/guide/advanced/data-fetching.md',
+              '/fr/guide/advanced/scroll-behavior.md',
+              '/fr/guide/advanced/lazy-loading.md'
+            ]
+          }
+        ]
+      }
     }
   }
-}
+})
