@@ -1,5 +1,6 @@
 set -e
-echo "Enter release version: "
+echo "Current version:" $(grep version package.json | sed -E 's/^.*"(4[^"]+)".*$/\1/')
+echo "Enter release version e.g. 3.3.0: "
 read VERSION
 
 read -p "Releasing v$VERSION - are you sure? (y/n)" -n 1 -r
@@ -7,27 +8,22 @@ echo    # (optional) move to a new line
 if [[ $REPLY =~ ^[Yy]$ ]]
 then
   echo "Releasing v$VERSION ..."
-  npm test
 
   # commit
-  npm version $VERSION --message "chore(release): %s"
   VERSION=$VERSION npm run build
   git add dist
-  git commit --amend --no-edit # merge with previous commit
+  git commit -m "build: bundle $VERSION"
+  npm version $VERSION --message "chore(release): %s"
 
-  echo "Please check the git history and press enter"
+  # changelog
+  npm run changelog
+  echo "Please check the git history and the changelog and press enter"
   read OKAY
+  git add CHANGELOG.md
+  git commit -m "chore(changelog): $VERSION"
 
   # publish
   git push origin refs/tags/v$VERSION
   git push
   npm publish
-
-  # changelog
-  npm run changelog
-  echo "Please check the changelog and press enter"
-  read OKAY
-  git add CHANGELOG.md
-  git commit -m "chore(changelog): $VERSION"
-  git push
 fi
