@@ -12,6 +12,3 @@ export function warn (condition: any, message: string) {
   }
 }
 
-export function isError (err: any): boolean {
-  return Object.prototype.toString.call(err).indexOf('Error') > -1
-}
